if (
    True
    # sdf
):
    print("hw")

if ((
    True
    # sdf
)):
    print("hw")

if ((
    # type: ignore
    True
)):
    print("hw")

if ((
    True
    # type: ignore
)):
    print("hw")

if (
    # a long comment about
    # the condition below
    (a or b)
):
    pass

def return_true():
    return (
        (
            True  # this comment gets removed accidentally
        )
    )

def return_true():
    return (True)  # this comment gets removed accidentally


if (
    # huh comment
    (True)
):
    ...

if (
    # huh
    (
        # comment
        True
    )
):
    ...



for target in iter:
    pass

for target in (1, 2, 3):
    pass

for target.attr in call():
    pass

for target[0] in x.attr:
    pass

for target in x <= y:
    pass

for target in a and b:
    pass

for a, b, c, in iter:
    pass

for (a, b) in iter:
    pass

for target in *x.attr:
    pass

for target in [1, 2]:
    pass

for *target in a, b, c,:
    pass
else:
    pass

for target in *x | y: ...
for target in *await x: ...
for target in await x: ...
for target in lambda x: x: ...
for target in x if True else y: ...

if x:
    for target in iter:
        pass
# This `else` is not part of the `try` statement, so don't raise an error
else:
    pass
